@@ -1,5 +1,5 @@
-`LoadBeatWFDB` <-
-function(HRVData,RecordName,RecordPath=".",annotator="qrs",verbose=FALSE) {
+LoadBeatWFDB <-
+function(HRVData, RecordName, RecordPath=".", annotator="qrs", verbose=FALSE) {
 #------------------------------
 # Loads beats from an wfdb file
 #	Uses rdann from wfdbtools
@@ -7,39 +7,43 @@ function(HRVData,RecordName,RecordPath=".",annotator="qrs",verbose=FALSE) {
 #	RecordName -> record containing beat positions
 #	RecordPath -> path
 #	annotator -> wfdb annotator parameter
-#	Verbose -> TRUE for verbose mode
 
-	if (verbose) {
+	if (!is.null(verbose)) {
+		cat("  --- Warning: deprecated argument, using SetVerbose() instead ---\n    --- See help for more information!! ---\n")
+		SetVerbose(HRVData,verbose)
+	}
+	
+	if (HRVData$Verbose) {
 		cat("** Loading beats positions for record:",RecordName,"**\n")
 	}
 	
 	dir=getwd()
-	if (verbose) {
+	if (HRVData$Verbose) {
 		cat("   Path:",RecordPath,"\n")
 	}
 	setwd(RecordPath)
 	
 	# Calls rdann to read beat annotations
 	command=paste("rdann -r ",RecordName," -a",annotator," -p \'N\' -x")
-	if (verbose) {
+	if (HRVData$Verbose) {
 		cat("   Command:",command,"\n")
 	}
 	x1=system(command,intern=TRUE)
 	x2=substring(x1,1,9)
 	beat=as.numeric(x2)
-	if (verbose) {
+	if (HRVData$Verbose) {
 		cat("   Number of beats:",length(beat),"\n")
 	}
 	
 	HRVData$Beat=data.frame(Time=beat)
 
 	if (is.null(HRVData$datetime)) {
-      if (verbose) {
+      if (HRVData$Verbose) {
          cat("   Reading header info for:",RecordName,"\n")
       }
-      HRVData = LoadHeaderWFDB(HRVData,RecordName,RecordPath,verbose)
+      HRVData = LoadHeaderWFDB(HRVData,RecordName,RecordPath)
    } else {
-      if (verbose) {
+      if (HRVData$Verbose) {
          cat("   Header info already present for:",RecordName,"\n")
       }
    }
